<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_AR" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo lleva tiempo.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="26"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor, &lt;a href=&apos;%1&apos;&gt;hacé una donación&lt;/a&gt; para apoyar el desarrollo de %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Reportá errores y enviá tus idea a %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="33"/>
        <source>Icon designed by %1.</source>
        <translation>Iconos diseñados por %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>El modo compacto es una contribución de %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="35"/>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>El soporte para proxy HTTP es una contribución de %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="38"/>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="66"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Desarrollado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia Pública General de GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="78"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Lo que siempre quisiste saber de %1 y nunca te animaste a preguntar</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="../src/downloaditem.cpp" line="295"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="298"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="301"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="317"/>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="320"/>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="323"/>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="329"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="332"/>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="335"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante(s)</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta es sólo una versión de demostración de %1.</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Sólo se pueden bajar videos de menos de %1 minutos, para probar la funcionalidad de descarga.</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="53"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="54"/>
        <source>Get the full version</source>
        <translation>Conseguí la versión completa</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="126"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Descarga(s)</numerusform><numerusform>%n Descarga(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="../src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Cambiar destino...</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Elegir el destino de la descarga</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Destino de la descarga cambiado.</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Las descargas en curso van a seguir bajándose al destino anterior.</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Bajando a: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="../src/downloadview.cpp" line="18"/>
        <location filename="../src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Play/Pausa</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Detener luego de la pista actual</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Pista previa</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Subir volumen</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Bajar volumen</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Avanzar rápido</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Retroceder rápido</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No videos</source>
        <translation>Sin videos</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="50"/>
        <source>No more videos</source>
        <translation>No hay más videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="105"/>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="106"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener y volver a la búsqueda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="112"/>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Skip to the next video</source>
        <translation>Siguiente video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <location filename="../src/MainWindow.cpp" line="644"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="120"/>
        <location filename="../src/MainWindow.cpp" line="645"/>
        <source>Pause playback</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <location filename="../src/MainWindow.cpp" line="728"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="127"/>
        <source>Go full screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="136"/>
        <source>&amp;Compact mode</source>
        <translation>&amp;Modo compacto</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Esconder la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="145"/>
        <source>Open the &amp;YouTube page</source>
        <translation>Abrir la página &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="146"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir al video en YouTube y pausar la reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="152"/>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar el &amp;link de YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="153"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar el link de YouTube del video al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="159"/>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar la &amp;URL del stream del video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="160"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar la &amp;URL del stream del video al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="167"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Borrar los videos seleccionados de la lista</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="173"/>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;arriba</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="174"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para arriba los videos seleccionados</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="180"/>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;abajo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para abajo los videos seleccionados</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="187"/>
        <source>&amp;Clear recent searches</source>
        <translation>&amp;Eliminar las búsquedas recientes</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="192"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Eliminar el historial de búsqueda. No se puede deshacer.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="199"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="200"/>
        <source>Bye</source>
        <translation>Chau</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="204"/>
        <source>&amp;Website</source>
        <translation>&amp;Sitio web</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="206"/>
        <source>%1 on the Web</source>
        <translation>%1 en la Web</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="210"/>
        <source>Make a &amp;donation</source>
        <translation>Hacer una &amp;donación</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="211"/>
        <source>Please support the continued development of %1</source>
        <translation>Apoyá el desarrollo de %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="217"/>
        <source>Info about %1</source>
        <translation>Información sobre %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="225"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="244"/>
        <source>Mute volume</source>
        <translation>Silenciar volumen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="246"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="277"/>
        <location filename="../src/MainWindow.cpp" line="959"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="278"/>
        <source>Show details about video downloads</source>
        <translation>Mostrar detalles sobre la descarga de videos</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="286"/>
        <source>&amp;Download</source>
        <translation>&amp;Bajar video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <source>Download the current video</source>
        <translation>Bajar el video actual</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="328"/>
        <source>&amp;Application</source>
        <translation>&amp;Programa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="336"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="362"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="439"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Con %1 subís el volumen, con %2 lo bajás</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="578"/>
        <location filename="../src/MainWindow.cpp" line="584"/>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="597"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Seguro que querés salir de %1 con una descarga en progreso?</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="598"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si cerrás %1 ahora, la descarga se va a cancelar.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="601"/>
        <source>Close and cancel download</source>
        <translation>Cerrar y cancelar descarga</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="602"/>
        <source>Wait for download to finish</source>
        <translation>Esperar a que termine la descarga</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="635"/>
        <source>Fatal error: %1</source>
        <translation>Error fatal: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="637"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="660"/>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="661"/>
        <source>Resume playback</source>
        <translation>Continuar reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="751"/>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Salir de pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="834"/>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="892"/>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="898"/>
        <source>Volume is muted</source>
        <translation>Volumen silenciado</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="901"/>
        <source>Volume is unmuted</source>
        <translation>Volumen activo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="908"/>
        <source>Maximum video definition set to %1</source>
        <translation>Definición máxima de video seteada en %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="944"/>
        <source>Your privacy is now safe</source>
        <translation>Tu privacidad ahora está segura</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="960"/>
        <source>Downloads complete</source>
        <translation>Descarga completa</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="33"/>
        <source>Most relevant</source>
        <translation>Más relevantes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="40"/>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="47"/>
        <source>Most viewed</source>
        <translation>Más visitados</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="489"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ahora podés pegar el link de YouTube en otra aplicación</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="497"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ahora podés pegar la URL del stream en otra aplicación</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="498"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>El link va a ser válido sólo por un tiempo limitado.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="594"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta es sólo la versión de demostración de %1.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="595"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Te permite probar la aplicación y ver si te funciona.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="598"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="599"/>
        <source>Get the full version</source>
        <translation>Conseguir la versión completa</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="625"/>
        <source>Downloading %1</source>
        <translation>Bajando %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="258"/>
        <source>Network error: %1</source>
        <translation>Error de conexión: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
        <source>%1 views</source>
        <translation>%1 visitas</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Detener descarga</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Mostrar en %1</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Abrir carpeta padre</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Reiniciar descarga</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="74"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="41"/>
        <source>Get the full version</source>
        <translation>Conseguir la versión completa</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="88"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Escribir</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="93"/>
        <source>a keyword</source>
        <translation>una palabra clave</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="94"/>
        <source>a channel</source>
        <translation>un canal</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="99"/>
        <source>to start watching videos.</source>
        <translation>para empezar a ver videos.</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="124"/>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="141"/>
        <source>Recent keywords</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Canales recientes</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="358"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Una nueva versión de %1 esta disponible. Por favor &lt;a href=&apos;%2&apos;&gt;actualice a la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="35"/>
        <source>Make yourself comfortable</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="186"/>
        <source>Cannot get video stream for %1</source>
        <translation>No puedo obtener el stream de video de %1</translation>
    </message>
    <message>
        <location filename="../src/video.cpp" line="204"/>
        <source>Network error: %1 for %2</source>
        <translation>Error de conexión: %1 para %2</translation>
    </message>
</context>
</TS>